@@ -9,7 +9,7 @@
 #define GIOP_CHUNK_ALIGN 8
 #define GIOP_CHUNK_SIZE (GIOP_CHUNK_ALIGN * 256)
 
-static GSList *send_buffer_list;
+static GSList *send_buffer_list = NULL;
 static GMutex *send_buffer_list_lock = NULL;
 
 static const char giop_zero_buf [GIOP_CHUNK_ALIGN * 10] = {0};
@@ -411,6 +411,8 @@ giop_send_buffer_write (GIOPSendBuffer *buf,
 	if (!blocking && retval == LINC_IO_QUEUED_DATA)
 		retval = 0;
 
+	/* FIXME: we need to flag the connection disconnected on fatal error */
+
 	LINC_MUTEX_UNLOCK (cnx->outgoing_mutex);
 
 	return retval;
