@@ -21,7 +21,9 @@ g_CORBA_Object_hash (gconstpointer key)
 	CORBA_Object obj = (gpointer) key;
 
 	retval = obj->type_qid;
-	g_slist_foreach (obj->profile_list, IOP_profile_hash, &retval);
+
+	g_assert (obj->object_key != NULL);
+	retval ^= IOP_ObjectKey_hash (obj->object_key);
 
 	return retval;
 }
@@ -42,13 +44,18 @@ g_CORBA_Object_equal (gconstpointer a, gconstpointer b)
 		for (cur2 = other_object->profile_list; cur2; cur2 = cur2->next) {
 			if (IOP_profile_equal (_obj, other_object,
 					       cur1->data, cur2->data)) {
-#if 0
-				char *a, *b;
-				a = IOP_profile_dump (_obj, cur1->data);
-				b = IOP_profile_dump (other_object, cur2->data);
-				fprintf (stderr, "Profiles match:\n'%s':%s\n'%s':%s\n",
-					 _obj->type_id, a, other_object->type_id, b);
-#endif
+#ifdef G_ENABLE_DEBUG
+			        if (_orbit_debug_flags & ORBIT_DEBUG_OBJECTS) {
+					char *a, *b;
+					a = IOP_profile_dump (_obj, cur1->data);
+					b = IOP_profile_dump (other_object, cur2->data);
+					fprintf (stderr, "Profiles match:\n'%s':%s\n'%s':%s\n",
+						           g_quark_to_string (_obj->type_qid), a,
+						           g_quark_to_string (other_object->type_qid), b);
+					g_free (a);
+					g_free (b);
+				}
+#endif /* G_ENABLE_DEBUG */
 				return TRUE;
 			}
 		}
@@ -139,16 +146,20 @@ ORBit_objref_find (CORBA_ORB   orb,
 
 	retval = ORBit_lookup_objref (&fakeme);
 
-#ifdef OBJECT_DEBUG
-	g_warning ("Lookup '%s' (%p) == %p", type_id, profiles, retval);
-	{
+	dprintf (OBJECTS, "Lookup '%s' (%p) == %p\n", type_id, profiles, retval);
+
+#ifdef G_ENABLE_DEBUG
+	if (_orbit_debug_flags & ORBIT_DEBUG_OBJECTS) {
 		GSList *l;
-		g_print ("Profiles: ");
-		for (l = profiles; l; l = l->next)
-			g_print ("%s", IOP_profile_dump (&fakeme, l->data));
-		g_print ("\n");
+		fprintf (stderr, "Profiles: ");
+		for (l = profiles; l; l = l->next) {
+			char *str;
+			fprintf (stderr, "%s", (str = IOP_profile_dump (&fakeme, l->data)));
+			g_free (str);
+		}
+		fprintf (stderr, "\n");
 	}
-#endif
+#endif /* G_ENABLE_DEBUG */
 
 	if (!retval) {
 		retval = ORBit_objref_new (orb, fakeme.type_qid);
@@ -205,7 +216,7 @@ ORBit_try_connection (CORBA_Object obj)
 	while (obj->connection) {
 		switch (LINC_CONNECTION (obj->connection)->status) {
 		case LINC_CONNECTING:
-			g_main_iteration(TRUE);
+			g_main_context_iteration(NULL, TRUE);
 			break;
 
 		case LINC_CONNECTED:
@@ -260,10 +271,10 @@ ORBit_object_get_connection (CORBA_Object obj)
 			if (ORBit_try_connection (obj)) {
 				obj->object_key = objkey;
 				obj->connection->orb_data = obj->orb;
-#ifdef OBJECT_DEBUG
-				fprintf (stderr, "Initiated a connection to '%s' '%s' '%s'\n",
+
+				dprintf (OBJECTS, "Initiated a connection to '%s' '%s' '%s'\n",
 					 proto, host, service);
-#endif
+
 				return obj->connection;
 			}
 		}
@@ -412,9 +423,12 @@ ORBit_marshal_object (GIOPSendBuffer *buf, CORBA_Object obj)
 	const char         *typeid;
 	CORBA_unsigned_long num_profiles;
 
-	if (obj)
+	if (obj) {
 		typeid = g_quark_to_string (obj->type_qid);
-	else
+		if (!typeid)
+			g_error ("Attempted to marshal a bogus / "
+				 "dead object %p type", obj);
+	} else
 		typeid = "";
 
 	giop_send_buffer_append_string (buf, typeid);
@@ -428,14 +442,18 @@ ORBit_marshal_object (GIOPSendBuffer *buf, CORBA_Object obj)
 		num_profiles = 0;
 	giop_send_buffer_append_aligned (buf, &num_profiles, 4);
 
-#ifdef OBJECT_DEBUG
-	fprintf (stderr, "Marshal object '%p'\n", obj);
-#endif
+	dprintf (OBJECTS, "Marshal object '%p'\n", obj);
+
 	if (obj)
 		for (cur = obj->profile_list; cur; cur = cur->next) {
-#ifdef OBJECT_DEBUG
-			fprintf (stderr, "%s\n", IOP_profile_dump (obj, cur->data));
-#endif
+#ifdef G_ENABLE_DEBUG
+			if (_orbit_debug_flags & ORBIT_DEBUG_OBJECTS) {
+				char *str;
+				fprintf (stderr, "%s\n",
+					 (str = IOP_profile_dump (obj, cur->data)));
+				g_free (str);
+			}
+#endif /* G_ENABLE_DEBUG */
 			IOP_profile_marshal (obj, buf, cur->data);
 		}
 }
@@ -465,6 +483,7 @@ CORBA_Object_is_a (CORBA_Object       obj,
 		   CORBA_Environment *ev)
 {
 	static GQuark  corba_object_quark = 0;
+	static GQuark  omg_corba_object_quark = 0;
 	CORBA_boolean  retval;
 	gpointer       args[] = { (gpointer *)&logical_type_id };
 	GQuark         logical_type_quark;
@@ -473,11 +492,18 @@ CORBA_Object_is_a (CORBA_Object       obj,
 		corba_object_quark = g_quark_from_static_string (
 			"IDL:CORBA/Object:1.0");
 
+	if (!omg_corba_object_quark)
+		omg_corba_object_quark = g_quark_from_static_string (
+			"IDL:omg.org/CORBA/Object:1.0");
+
 	logical_type_quark = g_quark_from_string (logical_type_id);
 
 	if (logical_type_quark == corba_object_quark)
 		return CORBA_TRUE;
 
+	if (logical_type_quark == omg_corba_object_quark)
+		return CORBA_TRUE;
+
 	if (!obj)
 		return CORBA_FALSE;
 
